pub struct AlterClusterReconfigurationV1 {
pub cluster_id: String,
pub cluster_name: String,
pub transition: ReconfigurationLifecycleV1,
pub target_size: String,
pub target_replication_factor: u32,
pub target_availability_zones: Vec<String>,
pub target_logging: ClusterReplicaLoggingV1,
pub deadline: Option<u64>,
}Expand description
A cluster-level transition in a background reconfiguration’s lifecycle.
deadline is the reconfiguration’s active deadline as a millisecond
mz_timestamp, recorded on every transition so an operator can correlate
the transition with the originating ALTER: on started and cancelled
the written/re-targeted record’s deadline, on timed-out and finalized
the just-cleared record’s. On finalized, comparing it to the event’s
occurrence time distinguishes an in-time cut-over from a late or forced
(ON TIMEOUT COMMIT) one.
Fields
cluster_id: Stringcluster_name: Stringtransition: ReconfigurationLifecycleV1target_size: Stringtarget_replication_factor: u32target_availability_zones: Vec<String>target_logging: ClusterReplicaLoggingV1deadline: Option<u64>Trait Implementations
Sourceimpl Arbitrary for AlterClusterReconfigurationV1
impl Arbitrary for AlterClusterReconfigurationV1
Sourcetype Parameters = (<String as Arbitrary>::Parameters, <String as Arbitrary>::Parameters, <ReconfigurationLifecycleV1 as Arbitrary>::Parameters, <String as Arbitrary>::Parameters, <u32 as Arbitrary>::Parameters, <Vec<String> as Arbitrary>::Parameters, <ClusterReplicaLoggingV1 as Arbitrary>::Parameters, <Option<u64> as Arbitrary>::Parameters)
type Parameters = (<String as Arbitrary>::Parameters, <String as Arbitrary>::Parameters, <ReconfigurationLifecycleV1 as Arbitrary>::Parameters, <String as Arbitrary>::Parameters, <u32 as Arbitrary>::Parameters, <Vec<String> as Arbitrary>::Parameters, <ClusterReplicaLoggingV1 as Arbitrary>::Parameters, <Option<u64> as Arbitrary>::Parameters)
arbitrary_with accepts for configuration
of the generated Strategy. Parameters must implement Default.Sourcetype Strategy = Map<(<String as Arbitrary>::Strategy, <String as Arbitrary>::Strategy, <ReconfigurationLifecycleV1 as Arbitrary>::Strategy, <String as Arbitrary>::Strategy, <u32 as Arbitrary>::Strategy, <Vec<String> as Arbitrary>::Strategy, <ClusterReplicaLoggingV1 as Arbitrary>::Strategy, <Option<u64> as Arbitrary>::Strategy), fn((String, String, ReconfigurationLifecycleV1, String, u32, Vec<String>, ClusterReplicaLoggingV1, Option<u64>)) -> AlterClusterReconfigurationV1>
type Strategy = Map<(<String as Arbitrary>::Strategy, <String as Arbitrary>::Strategy, <ReconfigurationLifecycleV1 as Arbitrary>::Strategy, <String as Arbitrary>::Strategy, <u32 as Arbitrary>::Strategy, <Vec<String> as Arbitrary>::Strategy, <ClusterReplicaLoggingV1 as Arbitrary>::Strategy, <Option<u64> as Arbitrary>::Strategy), fn((String, String, ReconfigurationLifecycleV1, String, u32, Vec<String>, ClusterReplicaLoggingV1, Option<u64>)) -> AlterClusterReconfigurationV1>
Strategy used to generate values of type Self.Sourcefn arbitrary_with(_top: Self::Parameters) -> Self::Strategy
fn arbitrary_with(_top: Self::Parameters) -> Self::Strategy
Sourceimpl Clone for AlterClusterReconfigurationV1
impl Clone for AlterClusterReconfigurationV1
Sourcefn clone(&self) -> AlterClusterReconfigurationV1
fn clone(&self) -> AlterClusterReconfigurationV1
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<'de> Deserialize<'de> for AlterClusterReconfigurationV1
impl<'de> Deserialize<'de> for AlterClusterReconfigurationV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Hash for AlterClusterReconfigurationV1
impl Hash for AlterClusterReconfigurationV1
Sourceimpl Ord for AlterClusterReconfigurationV1
impl Ord for AlterClusterReconfigurationV1
Sourcefn cmp(&self, other: &AlterClusterReconfigurationV1) -> Ordering
fn cmp(&self, other: &AlterClusterReconfigurationV1) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for AlterClusterReconfigurationV1
impl PartialEq for AlterClusterReconfigurationV1
Sourcefn eq(&self, other: &AlterClusterReconfigurationV1) -> bool
fn eq(&self, other: &AlterClusterReconfigurationV1) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for AlterClusterReconfigurationV1
impl PartialOrd for AlterClusterReconfigurationV1
impl Eq for AlterClusterReconfigurationV1
impl StructuralPartialEq for AlterClusterReconfigurationV1